#   REPLICATION

# Required packages ----
require(tidyverse)
require(reshape2)
require(scales)
require(flextable)

#   Data preparation ----
#   Load dataset
dataset <- readRDS("dataset_wide.rds")

# FIGURES ----
# Main text ----

#   Filter only CNS/COD/OLP
dataset_c <-
  dataset %>% filter(procedure_type == "CNS" |
                       procedure_type == "COD" |
                       procedure_type == "OLP") %>%
  filter(doc_proposal_complete_complexity == T)

#   Create commission annotations
Santer <- as.Date("01-23-1995", "%m-%d-%Y")
Marin <- as.Date("03-16-1999", "%m-%d-%Y")
Prodi <- as.Date("09-16-1999", "%m-%d-%Y")
Barroso_1 <- as.Date("11-22-2004", "%m-%d-%Y")
Barroso_2 <- as.Date("02-10-2010", "%m-%d-%Y")
Junker <- as.Date("11-01-2014", "%m-%d-%Y")
von_der_Leyen <- as.Date("12-01-2019", "%m-%d-%Y")

annotations <- list(annotate(x=Junker + 900,y=Inf+100,label="Juncker",vjust=1,geom="text",size=2),
                    annotate(x=Barroso_1+950,y=Inf,label="Barroso I",vjust=1,geom="text",size=2),
                    annotate(x=Barroso_2+900,y=Inf,label="Barroso II",vjust=1,geom="text",size=2),
                    annotate(x=Prodi+900,y=Inf,label="Prodi",vjust=1,geom="text",size=2),
                    annotate(x=Marin-1200,y=Inf,label="Santer",vjust=1,geom="text",size=2),
                    geom_vline(xintercept = Junker,linetype="dotted", color="grey60"),
                    geom_vline(xintercept = Marin,linetype="dotted", color="grey60"),
                    geom_vline(xintercept = Barroso_1,linetype="dotted", color="grey60"),
                    geom_vline(xintercept = Barroso_2,linetype="dotted", color="grey60"),
                    geom_vline(xintercept = Prodi,linetype="dotted", color="grey60"),
                    geom_vline(xintercept = von_der_Leyen,linetype="dotted", color="grey60"))

#   Figure 2, p. 11:    Evolution of policy complexity in the EU: six indicators  ----
Figure2 <- dataset_c %>%
  select(doc_proposal_struct_size_enacting,
         doc_proposal_avg_depth,
         doc_proposal_word_entropy_l,
         doc_proposal_lix,
         doc_proposal_ref_ext_enacting_rel,
         doc_proposal_ref_int_enacting_rel,
         e_proposal_legal_date) %>%
  `colnames<-` (c("Structural Size","Avg. Depth",
                  "Word Entropy", "Lix Score",
                  "External References per Article", "Internal References per Article",
                  "Date")) %>%
  melt(id.vars=c("Date")) %>%
  mutate(Year=format(as.Date(Date,"%Y"),"%Y")) %>%
  group_by(Year, variable) %>%
  mutate(mean_val=mean(value)) %>%
  ggplot(., aes(x=as.Date(Year,"%Y"), y=mean_val, group=variable, color=variable,fill=variable)) +
  geom_line()+
  geom_smooth(aes(x=Date,y=value))+
  theme_minimal()+
  scale_color_viridis_d()+
  scale_fill_viridis_d()+
  xlab("Date")+
  ylab("")+
  theme(text = element_text(size=7))+
  theme(legend.position = "none",
        strip.text.x = element_text(size = 8, color = "grey30", face = "bold",vjust=3),
        panel.spacing = unit(1.5, "lines"))+
  facet_wrap(~variable, scales = "free", ncol=2)+
  scale_x_date(breaks = pretty_breaks(6))+
  annotations

#   jpeg("figure2.jpg", width = 15, height=18, units="cm", res=400)
Figure2
#   dev.off()

#   Figure 3, p. 14:    Evolution of policy complexity indicators across policy domains ----
t1 <- dataset_c %>%
  mutate(r1= scale(doc_proposal_struct_size_enacting),
         r2 = scale(doc_proposal_avg_depth),
         r3 = scale(doc_proposal_word_entropy_l),
         r4 = scale(doc_proposal_lix),
         r5 = scale(doc_proposal_ref_ext_enacting_rel),
         r6 = scale(doc_proposal_ref_int_enacting_rel),
         total = scale((r1+r2+r3+r4+r5+r6)/6)
  ) %>%
  select(
    doc_proposal_struct_size_enacting,
    doc_proposal_avg_depth,
    doc_proposal_word_entropy_l,
    doc_proposal_lix,
    doc_proposal_ref_ext_enacting_rel,
    doc_proposal_ref_int_enacting_rel,
    e_proposal_legal_date,
    procedure_reference,
    total
  ) %>%
  `colnames<-` (
    c(
      "Structural Size",
      "Avg. Depth",
      "Word Entropy",
      "Lix Score",
      "External References per Article",
      "Internal References per Article",
      "Date",
      "ID",
      "Scaled"
    )
  )

eurovoc <- dataset_c[, grep("eurovoc_\\d\\d*", names(dataset_c))]
eurovoc$eurovoc_76_Int.Organisation <- eurovoc$eurovoc_76_international
eurovoc$eurovoc_76_international <- NULL

eurovoc <- bind_cols(t1, eurovoc)
eurovoc <- pivot_longer(eurovoc, cols = names(eurovoc[10:30])) %>%
  na.omit %>%
  filter(value == T) %>%
  mutate(name = stringr::str_to_title(gsub("eurovoc_\\d\\d_","",name)))

Figure3 <- eurovoc %>%
  mutate(Year=as.Date(format(Date,"%Y"),"%Y")) %>%
  group_by(Year, name) %>%
  mutate(mean_total=mean(Scaled)) %>%
  ggplot(aes(x=as.Date(Date), y=Scaled, color=name, fill=name)) +
  geom_smooth()+
  geom_line(aes(x=as.Date(Year,"%Y"),y=mean_total, color=name, group=name))+
  theme_minimal()+
  xlab("Date")+
  ylab("Aggregated standardised complexity")+
  theme(legend.position = "none",
        strip.text.x = element_text(size = 11, color = "grey30", face = "bold",vjust=3),
        panel.spacing = unit(2.5, "lines"))+
  facet_wrap(~name, ncol=3)+
  scale_x_date(breaks = pretty_breaks(6))+
  annotations

#   jpeg("figure3.jpg", width = 20, height=25, units="cm", res=400)
Figure3
#   dev.off()

#   Apendix ----
#   Figure D1, p. 6 :   Correlation matrix for the complexity indicators in the dataset ----

figure_d1 <- dataset %>%
  filter(doc_proposal_complete_complexity == T) %>%
  select(doc_proposal_struct_size_enacting,
         doc_proposal_avg_depth,
         doc_proposal_word_entropy_l,
         doc_proposal_lix,
         doc_proposal_ref_ext_enacting_rel,
         doc_proposal_ref_int_enacting_rel) %>%
  `colnames<-` (c("Structural Size","Avg. Depth",
                  "Word Entropy", "Lix Score",
                  "External References per Article", "Internal References per Article")) %>%
  GGally::ggcorr(low = "blue", mid = "white", high = "red",label=T, legend.size = 4, label_size = 2,
                 size=1.5,layout.exp = 6, hjust=1)

#   jpeg("FigureD.jpg", width = 10, height = 10, unit="cm", res = 400)
figure_d1
#   dev.off()

#   Figures D2 to D7, p. 7 to p. 12:    Indicators by Eurovoc Domain ----
#   Define function for plot

plot_eurovoc <- function(data, variable) {
  data <- data
  variable <- c(variable)

  data %>%
    mutate(Year=as.Date(format(Date,"%Y"),"%Y")) %>%
    group_by(Year, name) %>%
    mutate(mean_total=mean(.data[[variable]])) %>%
    ggplot(aes(x=as.Date(Date), y=.data[[variable]], color=name, fill=name)) +
    geom_smooth()+
    geom_line(aes(x=as.Date(Year,"%Y"),
                  y=mean_total,
                  color=name,
                  group=name))+
    theme_minimal()+
    xlab("Date")+
    ylab(variable)+
    theme(legend.position = "none",
          text = element_text(size=6),
          strip.text.x = element_text(size = 8, color = "grey30", face = "bold",vjust=3),
          panel.spacing = unit(1, "lines"))+
    facet_wrap(~name, ncol=3)+
    scale_x_date(breaks = pretty_breaks(6))+
    annotations
}

#   Create plot per Indicator
figure_d2 <- plot_eurovoc(eurovoc,"Structural Size")
figure_d3 <- plot_eurovoc(eurovoc,"Avg. Depth")
figure_d4 <- plot_eurovoc(eurovoc,"Word Entropy")
figure_d5 <- plot_eurovoc(eurovoc,"Lix Score")
figure_d6 <- plot_eurovoc(eurovoc,"External References per Article")
figure_d7 <- plot_eurovoc(eurovoc,"Internal References per Article")

#   jpeg("figure_d2.jpg", width = 20, height=25, units="cm", res=400)
figure_d2
#   dev.off()

#   jpeg("figure_d3.jpg", width = 20, height=25, units="cm", res=400)
figure_d3
#   dev.off()

#   jpeg("figure_d4.jpg", width = 20, height=25, units="cm", res=400)
figure_d4
#   dev.off()

#   jpeg("figure_d5.jpg", width = 20, height=25, units="cm", res=400)
figure_d5
#   dev.off()

#   jpeg("figure_d6.jpg", width = 20, height=25, units="cm", res=400)
figure_d6
#   dev.off()

#   jpeg("figure_d7.jpg", width = 20, height=25, units="cm", res=400)
figure_d7
#   dev.off()

#   Figure D8, p. 13:   Complexity by legislative procedure per indicator ----
figure_d8 <- dataset_c %>%
  select(doc_proposal_struct_size_enacting,
         doc_proposal_avg_depth,
         doc_proposal_word_entropy_l,
         doc_proposal_lix,
         doc_proposal_ref_ext_enacting_rel,
         doc_proposal_ref_int_enacting_rel,
         e_proposal_legal_date, procedure_type) %>%
  `colnames<-` (c("Structural Size","Avg. Depth",
                  "Word Entropy", "Lix Score",
                  "External References per Article", "Internal References per Article",
                  "Date","Type")) %>%
  mutate(Type=ifelse(Type == "COD" | Type == "OLP", "COD / OLP",Type)) %>%
  melt(id.vars=c("Date","Type")) %>%
  ggplot(aes(x=Date, y=value, group=Type, color=Type,fill=Type)) +
  geom_smooth(method="lm")+
  theme_minimal()+
  xlab("Date")+
  ylab("")+
  theme(strip.text.x = element_text(size = 11, color = "grey30", face = "bold",vjust=3),
        panel.spacing = unit(2.5, "lines"))+
  facet_wrap(~variable, scales = "free", ncol=2)+
  scale_x_date(breaks = pretty_breaks(6))+
  annotations

#   jpeg("figure_d8.jpg", width = 15, height=18, units="cm", res=400)
figure_d8
#   dev.off()

# TABLES ----

# Main Text ----

# Table 2: Descriptive statistics ----
summary_vars <-
  c(
    'doc_proposal_struct_size',
    'doc_proposal_avg_depth',
    'doc_proposal_word_entropy_l',
    'doc_proposal_lix',
    'doc_proposal_ref_int_enacting_rel',
    'doc_proposal_ref_ext_enacting_rel'
  )

summary_vars <-
  data.frame(
    'doc_proposal_struct_size' = 'Structural size',
    'doc_proposal_avg_depth' = 'Avg. depth',
    'doc_proposal_word_entropy_l' = 'Word entropy',
    'doc_proposal_lix' = 'Lix score',
    'doc_proposal_ref_int_enacting_rel' = 'Avg. int. references/article',
    'doc_proposal_ref_ext_enacting_rel' = 'Avg. ext. references/article'
  )
tab_summary <- data.frame()

for (i in 1:NROW(names(summary_vars))){

  varname <- names(summary_vars)[i]

  var <- dataset[which(dataset$doc_proposal_complete_complexity),varname]

  tab_summary <-
    dplyr::bind_rows(
      tab_summary,
      c(
        'Indicator' = summary_vars[[i]],
        'N' = NROW(var),
        'Min' = min(var),
        'Mean' = mean(var),
        'Max' = max(var),
        'SD' = sd(var)
      )
    )

}

tab_summary <- type.convert(tab_summary)

flextable::flextable(tab_summary) %>%
  add_header_lines(values=c("Descriptive statistics (complete proposal observations only)")) %>%
  bold(part="header") %>%
  set_table_properties(layout = "autofit") %>%
  valign (valign = "top") %>%
  align(align='center') %>%
  align_nottext_col(align='right') %>%
  align_text_col(align='left') %>%
  colformat_num(digits=2)

# Appendix ----

# Table A1: Bad formatting ----

temp_dataset <- dataset
temp_dataset$doc_proposal__formatting <- temp_dataset$doc_proposal__bad_formatting_reason
temp_dataset[which(!(temp_dataset$doc_proposal__bad_formatting)),]$doc_proposal__formatting <- 'None'
temp_dataset[which(grepl('pdfcol', temp_dataset$doc_proposal__bad_formatting_reason)),]$doc_proposal__formatting <- NA

temp_dataset[which(temp_dataset$doc_proposal__bad_formatting_reason=='doneatmissing;'),]$doc_proposal__formatting <- "No formal end"
temp_dataset[which(temp_dataset$doc_proposal__bad_formatting_reason=='newline;'),]$doc_proposal__formatting <- "Missing line-breaks"
temp_dataset[which(temp_dataset$doc_proposal__bad_formatting_reason=='newline;doneatmissing;'),]$doc_proposal__formatting <- "No formal end + missing line-breaks"
temp_dataset[which(temp_dataset$doc_proposal__bad_formatting_reason=='multipleproposals;'),]$doc_proposal__formatting <- "Multiple proposals in document"
temp_dataset[which(temp_dataset$doc_proposal__bad_formatting_reason=='newline;multipleproposals;'),]$doc_proposal__formatting <- "Multiple proposals + missing line-break"

df_formatting <-
  proc_freq(
    temp_dataset,
    row = c('doc_proposal__formatting'),
    col = c('doc_proposal_complete_complexity'),
    include.column_percent = FALSE,
    include.table_percent = FALSE,
  )[["body"]][["dataset"]]

df_formatting <- df_formatting[df_formatting$label!='Row Pct',]
df_formatting$label <- NULL

names(df_formatting) <- c('Formatting problems', 'No', 'Yes', 'Total')

flextable(df_formatting)%>%
  add_header_row(values=c("", "Complexity indicators available"), colwidths=c(1,3)) %>%
  align(i=1, align = "left", part='header') %>%
  bold(part="header") %>%
  bold(j=c(4)) %>%
  bold(i=NROW(df_formatting)) %>%
  valign (valign = "top") %>%
  align_nottext_col(align='right') %>%
  align_text_col(align='left') %>%
  set_table_properties(layout='autofit', width = 0.9)

# Table D3: Procedure by instrument ----

labels_proc_types <- c('COD/OLP', 'AVC/APP', 'ACC', 'CNS', 'COD/OLP', 'NLE', 'CNS/SLP', 'NA')

temp_dataset <- dataset
temp_dataset[which(temp_dataset$procedure_type == 'COD' | temp_dataset$procedure_type == 'OLP'), 'procedure_type']<- 'COD/OLP'
temp_dataset[which(temp_dataset$procedure_type == 'APP' | temp_dataset$procedure_type == 'AVC'), 'procedure_type']<- 'AVC/APP'
temp_dataset[which(temp_dataset$procedure_type == 'CNS' | temp_dataset$procedure_type == 'SLP'), 'procedure_type']<- 'CNS/SLP'
temp_dataset[which(is.na(temp_dataset$procedure_type)), 'procedure_type'] <- 'NA'
temp_dataset[which(!(temp_dataset$procedure_type %in% labels_proc_types)), 'procedure_type'] <- 'Other'
temp_dataset <- temp_dataset[which(temp_dataset$procedure_type %in% c(labels_proc_types, 'Other')),]

label_leg_instr <- c('Regulation', 'Directive', 'Decision', 'NA')

temp_dataset[which(is.na(temp_dataset$doc_proposal_leg_instr)), 'doc_proposal_leg_instr'] <- 'NA'
temp_dataset[which(!(temp_dataset$doc_proposal_leg_instr %in% label_leg_instr)), 'doc_proposal_leg_instr'] <- 'Other'

df_proc_instr <-
  proc_freq(
    temp_dataset[which(temp_dataset$doc_proposal_complete_complexity), ],
    'procedure_type',
    'doc_proposal_leg_instr',
    include.row_percent = TRUE,
    include.column_percent = FALSE,
    include.table_percent = FALSE,
    include.column_total = TRUE,
    include.row_total = TRUE,
    include.header_row = TRUE,
  )[["body"]][["dataset"]]

df_proc_instr<-df_proc_instr[which(df_proc_instr$label!="Row Pct"),]
names(df_proc_instr)[1] <- 'Procedure type'

# Sorting
instr_order <- c('Procedure type', 'Regulation', 'Directive', 'Decision', 'Other', 'NA', 'Total')
df_proc_instr <- df_proc_instr[,instr_order]

proc_type_order <- c('ACC', 'AVC/APP', 'CNS/SLP', 'COD/OLP', 'NLE', 'Other', 'NA', 'Total')
df_proc_instr <- df_proc_instr[ order(match(df_proc_instr$`Procedure type`, proc_type_order)),]

df_proc_instr[,'label'] <- NULL
names(df_proc_instr)[1:4] <- c('Procedure', 'Regul.', 'Direct.', 'Decis.')

flextable::flextable(df_proc_instr) %>%
  add_header_row(values=c("", "Legislative instrument", ""), colwidths=c(1,4,2)) %>%
  #add_header_lines(values=c("Procedure type by legislative instrument")) %>%
  bold(part="header") %>%
  bold(j=c(7)) %>%
  bold(i=NROW(df_proc_instr)) %>%
  valign (valign = "top") %>%
  align_nottext_col(align='right') %>%
  align_text_col(align='left') %>%
  set_table_properties(layout='autofit', width = 1)

